@@ -1,6 +1,6 @@
 ;;; phps-mode-automation-grammar --- Grammar -*- lexical-binding: t -*-
 
-;; Copyright (C) 2018-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2018-2024  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -9,13 +9,6 @@
 ;;; Code:
 
 
-;; Just to stop linter from complaining
-
-(defvar
-  phps-mode-parser-tokens
-  nil
-  "Tokens for parser.")
-
 (defvar
   phps-mode-automation-grammar--lr--allow-default-conflict-resolution
   t
@@ -33,12 +26,12 @@
 
 (defvar
   phps-mode-automation-grammar--copyright
-  ";; Copyright (C) 2018-2023  Free Software Foundation, Inc.\n\n;; This file is not part of GNU Emacs.\n\n\n"
+  ";; Copyright (C) 2018-2024  Free Software Foundation, Inc.\n\n;; This file is not part of GNU Emacs.\n\n\n"
   "Copyright contents for parser.")
 
 (defvar
   phps-mode-automation-grammar--header
-  "\n(defvar-local\n phps-mode-parser-tokens\n nil\n \"Tokens for parser.\")\n\n(define-error\n 'phps-parser-error\n \"PHPs Parser Error\")\n\n"
+  "\n(require 'phps-mode-lexer)\n\n"
   "Header contents for parser.")
 
 (defvar
@@ -53,20 +46,41 @@
 
 (defvar
   phps-mode-automation-grammar--lex-analyzer-function
-  (lambda (buffer-index)
-    (let ((result (gethash buffer-index phps-mode-parser-tokens))
-          (token))
-      (when result
-        (cond
-         ((numberp result)
-          (setq
-           phps-mode-parser-lex-analyzer--move-to-index-flag
-           result))
-         ((listp result)
-          (setq
-           token
-           result))))
-      token))
+  (lambda (index old-state)
+    (let* ((lexer-response
+            (phps-mode-lexer--re2c index old-state))
+           (tokens
+            (nth 0 lexer-response))
+           (move-to-index
+            (nth 1 lexer-response))
+           (new-state
+            (nth 2 lexer-response)))
+
+
+      (unless move-to-index
+        (let ((token-type (car (car tokens))))
+          (cond
+
+           ((or
+             (equal token-type 'T_OPEN_TAG)
+             (equal token-type 'T_COMMENT)
+             (equal token-type 'T_DOC_COMMENT)
+             )
+            (setq
+             move-to-index
+             (cdr (cdr (car tokens)))))
+
+           ((equal token-type 'T_OPEN_TAG_WITH_ECHO)
+            (setf (car (car tokens)) 'T_ECHO))
+
+           ((equal token-type 'T_CLOSE_TAG)
+            (setf (car (car tokens)) ";"))
+
+           )
+
+          ))
+
+      (list tokens move-to-index new-state)))
   "The custom lex-analyzer.")
 
 (defvar
